#
# spec file for package tree-sitter-cpp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name cpp
Name:           tree-sitter-cpp
Version:        0.23.4
Release:        1.1
Summary:        C++ grammar for tree-sitter
License:        MIT
URL:            https://github.com/tree-sitter/tree-sitter-cpp
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  tree-sitter
BuildRequires:  treesitter_grammar_src(tree-sitter-c)
%treesitter_grammars %{_name}

%description
%{summary}.

%prep
%autosetup

%build
%treesitter_configure
%treesitter_build

%install
%treesitter_install
%treesitter_devel_install

#neovim stuff
install -d %{buildroot}%{_libdir}/tree_sitter
ln -s %{_libdir}/lib%{name}.so %{buildroot}%{_libdir}/tree_sitter/%{_name}.so

%files
%license LICENSE
%treesitter_files
%{_libdir}/tree_sitter/%{_name}.so
%if 0%{?suse_version} < 1600
%dir %{_libdir}/tree_sitter
%endif

%treesitter_devel_package

%changelog
* Thu Dec  5 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 0.23.4:
  * fix: disallow recursive grammar.js files to be included
- update to 0.23.3:
  * build: move tree-sitter-c to dependencies
  * ci(publish): add attestations and generate parser
- update to 0.23.2:
  * build: update bindings
  * chore: regenerate
- update to 0.23.1:
  * build: bump tree-sitter-c to 0.23.1
  * chore: generate
  * lambda expressions: support capture syntax through cpp20
- update to 0.23.0:
  * build: update bindings
  * chore: generate
  * feat: allow semicolon in field declaration list items
  * feat: add raw_string_literal to _string
  * feat: support constexpr-prefixed friend declarations
  * fix: do not give higher precedence to a token 0
  * fix: inline the virtual node
  * feat: bump tree-sitter-c to 0.23.0
  * fix(go): correct test
  * chore: fix line endings
- switch to download_files service
- add neovim links
- adapt spec file to other grammars
- add devel package
* Thu Aug  1 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 0.22.3:
  * Add tests for template/comparison ambiguities
  * Fix ambiguity between template and comparison
  * fix: remove `choice` wrapper around 'virtual'
  * fix(query): remove duplicate rule
* Mon Apr 29 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Update to version 0.22.0:
  * feat: support reference declarators in types
  * feat: add optional attribute declarations after 'namespace'
  * feat: support pure virtual destructors
  * fix: specifier and virtual do not strictly require each other
  * fix(scanner): only call memcpy if `length` is greater than 0
  * feat(scanner): use alloc header
* Sun Feb 25 2024 Björn Bidar <bjorn.bidar@thaodan.de>
- Initial packaging for openSUSE
- Update to version 0.20.5:
  * fix: allow qualified identifiers in field expressions
  * fix: give for statement bodies a higher `dynamic` precedence to avoid parse errors
  * fix(scanner): return false during error recovery
  * chore: update tree-sitter-c
  * docs: update badges
  * chore(scanner): formatting improvements
  * fix: hide aliased rule
